Learn R Programming

ChinAPIs (version 0.1.0)

get_china_energy_use: Get China's Energy Use (kg of oil equivalent per capita) from World Bank

Description

Retrieves China's energy use per capita, measured in kilograms of oil equivalent, for the years 2010 to 2022 using the World Bank Open Data API. The indicator used is EG.USE.PCAP.KG.OE.

Usage

get_china_energy_use()

Arguments

Value

A tibble with the following columns:

  • indicator: Indicator name (e.g., "Energy use (kg of oil equivalent per capita)")

  • country: Country name ("China")

  • year: Year of the data (integer)

  • value: Energy use in kilograms of oil equivalent per capita

Details

This function sends a GET request to the World Bank API. If the API request fails or returns an error status code, the function returns NULL with an informative message.

See Also

Examples

Run this code
if (interactive()) {
  get_china_energy_use()
}

Run the code above in your browser using DataLab