Get Official Public Holidays in China for a Given Year
Source:R/get_china_holidays.R
get_china_holidays.RdRetrieves the list of official public holidays in China for a specific year using the Nager.Date public holidays API.
Value
A tibble with the following columns:
date: Date of the holiday (classDate)local_name: Holiday name in the local languagename: Holiday name in English
Returns NULL if the API request fails.
Examples
if (interactive()) {
get_china_holidays(2024)
}