Learn R Programming

ChinAPIs (version 0.1.1)

get_china_hospital_beds: Get Hospital Beds per 1,000 People in China from World Bank

Description

Retrieves data on the number of hospital beds per 1,000 people in China from 2010 to 2022 using the World Bank Open Data API. The indicator used is SH.MED.BEDS.ZS.

Usage

get_china_hospital_beds()

Arguments

Value

A tibble with the following columns:

  • indicator: Indicator name (e.g., "Hospital beds (per 1,000 people)")

  • country: Country name ("China")

  • year: Year of the data (integer)

  • value: Hospital beds per 1,000 people (numeric)

Details

This function sends a GET request to the World Bank API. If the API request fails or returns an error status code, the function returns NULL with an informative message.

See Also

Examples

Run this code
if (interactive()) {
  get_china_hospital_beds()
}

Run the code above in your browser using DataLab