Learn R Programming

ChinAPIs (version 0.1.1)

get_china_holidays: Get Official Public Holidays in China for a Given Year

Description

Retrieves the list of official public holidays in China for a specific year using the Nager.Date public holidays API.

Usage

get_china_holidays(year)

Value

A tibble with the following columns:

  • date: Date of the holiday (class Date)

  • local_name: Holiday name in the local language

  • name: Holiday name in English

Returns NULL if the API request fails.

Arguments

year

An integer indicating the year (e.g., 2024).

Examples

Run this code
if (interactive()) {
  get_china_holidays(2024)
}

Run the code above in your browser using DataLab